@@ -1,7 +1,7 @@
 package Complete::Common;
 
-our $DATE = '2015-11-29'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2016-01-07'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,6 +27,7 @@ our %arg_word = (
 
 our $OPT_CI          = ($ENV{COMPLETE_OPT_CI}          // 1) ? 1:0;
 our $OPT_WORD_MODE   = ($ENV{COMPLETE_OPT_WORD_MODE}   // 1) ? 1:0;
+our $OPT_CHAR_MODE   = ($ENV{COMPLETE_OPT_CHAR_MODE}   // 1) ? 1:0;
 our $OPT_FUZZY       = ($ENV{COMPLETE_OPT_FUZZY}       // 1)+0;
 our $OPT_MAP_CASE    = ($ENV{COMPLETE_OPT_MAP_CASE}    // 1) ? 1:0;
 our $OPT_EXP_IM_PATH = ($ENV{COMPLETE_OPT_EXP_IM_PATH} // 1) ? 1:0;
@@ -47,7 +48,7 @@ Complete::Common - Common stuffs for completion routines
 
 =head1 VERSION
 
-This document describes version 0.21 of Complete::Common (from Perl distribution Complete-Common), released on 2015-11-29.
+This document describes version 0.22 of Complete::Common (from Perl distribution Complete-Common), released on 2016-01-07.
 
 =head1 DESCRIPTION
 
@@ -76,8 +77,21 @@ all available word even non-adjacent ones. For example, if you have C<dua-d> and
 the choices are (C<dua-tiga>, C<dua-empat>, C<dua-lima-delapan>) then
 C<dua-lima-delapan> will match because C<d> matches C<delapan> even though the
 word is not adjacent. This is convenient when you have strings that are several
-or many words long: you can just type the word that you remember even though the
-word is positioned near the end of the string.
+or many words long: you can just type the starting letters of some of the words
+instead of just the starting letters of the whole string (which might need to be
+quite long before producing a unique match).
+
+=head2 C<$Complete::Common::OPT_CHAR_MODE> => bool (default: from COMPLETE_OPT_CHAR_MODE or 1)
+
+If set to 1, enable character-mode matching.
+
+This mode is like word-mode matching, except it works on a
+character-by-character basis. Basically, it will match if a word contains any
+letters of the string in the correct order. For example, C<ap> will match C<ap>,
+C<amp>, C<slap>, or C<cramp> (but will not match C<pa> or C<pram>).
+
+Character-mode matching is normally only done when exact matching and word-mode
+fail to return any candidate.
 
 =head2 C<$Complete::Common::OPT_FUZZY> => int (default: from COMPLETE_OPT_FUZZY or 1)
 
@@ -85,8 +99,8 @@ Enable fuzzy matching (matching even though there are some spelling mistakes).
 The greater the number, the greater the tolerance. To disable fuzzy matching,
 set to 0.
 
-Fuzzy matching is normally only done when exact matching and word-mode matching
-fail to return any candidate.
+Fuzzy matching is normally only done when exact matching, word-mode, and
+char-mode matching fail to return any candidate.
 
 =head2 C<$Complete::Common::OPT_MAP_CASE> => bool (default: from COMPLETE_OPT_MAP_CASE or 1)
 
@@ -174,7 +188,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
